1. ##

2. ##

3. ##

4. ##

    	Docker steps:

    				install docker

    				start the docker service

    					[xonsh] sudo systemctl start docker; sudo systemctl status docker

    				create a docker container from an image

    					[ ] list images:
    						[xonsh] docker image list

    					[ ] list containers:
    						[xonsh] docker container list

    					[ ] start container:
    						# [xonsh] docker run -v /path_inside_host:/path_inside_container -it ubuntu /bin/bash

    						docker run -it ubuntu /bin/bash

    					[ ] save container to image archive

    				start container from image archive